@@ -12,7 +12,7 @@ Fixture for loading the chemical reference and pdbx_core collections in a loca m
 
 """
 
-__docformat__ = "restructuredtext en"
+__docformat__ = "google en"
 __author__ = "John Westbrook"
 __email__ = "jwest@rcsb.rutgers.edu"
 __license__ = "Apache 2.0"
